#[non_exhaustive]pub enum DistLoadVoltageModel {
ConstantPower {
v_nom: Vec<f64>,
},
ConstantCurrent {
v_nom: Vec<f64>,
},
ConstantImpedance {
v_nom: Vec<f64>,
},
Zip {
v_nom: Vec<f64>,
alpha_z: Vec<f64>,
alpha_i: Vec<f64>,
alpha_p: Vec<f64>,
beta_z: Vec<f64>,
beta_i: Vec<f64>,
beta_p: Vec<f64>,
},
Exponential {
v_nom: Vec<f64>,
gamma_p: Vec<f64>,
gamma_q: Vec<f64>,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ConstantPower
Constant power load. v_nom is volts per active phase when the source
states it.
ConstantCurrent
Constant current load. v_nom is volts per active phase.
ConstantImpedance
Constant impedance load. v_nom is volts per active phase.
Zip
ZIP load coefficients by active phase. v_nom is volts per active
phase; alpha terms apply to active power and beta terms to reactive
power.
Fields
Exponential
Exponential voltage model by active phase. v_nom is volts per active
phase.
Implementations